"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebpackBar = void 0;
/*
 * @file:
 * @author: wence
 */
var utils_1 = __importDefault(require("../utils"));
var WebpackBar = /** @class */ (function () {
    function WebpackBar(options) {
        this.progress = 0;
        this.width = (options === null || options === void 0 ? void 0 : options.width) || 25;
        this.start = null;
        this.end = null;
        this.stream = process.stderr;
    }
    WebpackBar.prototype.update = function (progress) {
        this.progress = this.getCurProgress(progress);
        if (this.start === null) {
            this.start = Date.now();
        }
        this.end = Date.now();
        this.renderBar();
    };
    WebpackBar.prototype.getCurProgress = function (progress) {
        if (progress < 0) {
            return 0;
        }
        if (progress > 1) {
            return 100;
        }
        return Math.round(progress * 10000) / 100;
    };
    WebpackBar.prototype.getTimeConsumed = function () {
        if (typeof this.end !== 'number' || typeof this.start !== 'number') {
            return 0;
        }
        return ((this.end - this.start) / 1000).toFixed(2);
    };
    WebpackBar.prototype.renderBar = function () {
        var w = (this.progress / 100) * this.width;
        var bar = Array.from({ length: this.width })
            .map(function (_, index) {
            return index < w ? utils_1.default.chalk.blue('█') : utils_1.default.chalk.gray('█');
        }).join('');
        this.stream.cursorTo(0);
        var str = 'building ['
            + bar
            + ("] " + this.progress + "% " + this.getTimeConsumed() + "s");
        // 当到100时要换行 \n 无法使用clearLine清除
        if (this.progress === 100) {
            str += '\n';
            this.start = null;
            this.end = null;
        }
        this.stream.write(str);
        this.stream.clearLine(1);
    };
    return WebpackBar;
}());
exports.WebpackBar = WebpackBar;
exports.default = new WebpackBar();
