"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArray = (this && this.__spreadArray) || function (to, from) {
    for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
    return to;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var chalk_1 = __importDefault(require("chalk"));
function noop() {
    return null;
}
function getEnv() {
    return process.env.NODE_ENV;
}
function isDev() {
    return process.env.NODE_ENV === 'development';
}
function isProduction() {
    return process.env.NODE_ENV === 'production';
}
function isFunction(func) {
    return Object.prototype.toString.call(func) === '[object Function]';
}
function isObject(obj) {
    return Object.prototype.toString.call(obj) === '[object Object]';
}
function isString(str) {
    return Object.prototype.toString.call(str) === '[object String]';
}
function loggerPrefix(message, options) {
    var _a = (options || {}).name, name = _a === void 0 ? 'info' : _a;
    console.log(chalk_1.default.blue("react-build-cli:" + name) + " " + message);
}
function success(info) {
    loggerPrefix(chalk_1.default.green('✔') + " " + chalk_1.default.blue(info));
}
function logger(info) {
    loggerPrefix(chalk_1.default.green(info));
}
function warning(info) {
    loggerPrefix(chalk_1.default.yellow(info));
}
function error(info) {
    loggerPrefix(chalk_1.default.red(info));
}
function requireModule(modulePath) {
    return require(modulePath).default || require(modulePath);
}
function getWebpackProxyPath(webpackConfig) {
    var _a, _b;
    if (webpackConfig && webpackConfig.devServer && isObject(webpackConfig.devServer.proxy)) {
        var proxyPath = Object.keys(((_a = webpackConfig.devServer) === null || _a === void 0 ? void 0 : _a.proxy) || {});
        var resultMapStrings_1 = [];
        proxyPath.forEach(function (key) {
            var _a;
            var proxy = (((_a = webpackConfig.devServer) === null || _a === void 0 ? void 0 : _a.proxy) || {})[key];
            if (isObject(proxy)) {
                resultMapStrings_1.push(key + " => " + proxy.target);
            }
            else if (isString(proxy)) {
                resultMapStrings_1.push(key + " => " + proxy);
            }
        });
        return resultMapStrings_1;
    }
    if (webpackConfig && webpackConfig.devServer && Array.isArray(webpackConfig.devServer.proxy)) {
        return (((_b = webpackConfig.devServer) === null || _b === void 0 ? void 0 : _b.proxy) || []).reduce(function (resultMapStrings, proxy) {
            if (Array.isArray(proxy.path)) {
                resultMapStrings = __spreadArray(__spreadArray([], resultMapStrings), proxy.path);
            }
            else if (isString(proxy.path)) {
                resultMapStrings.push(proxy.path || '');
            }
            return resultMapStrings;
        }, []);
    }
    return [];
}
function mergeBabelConfig(baseConfig, mergeConfig) {
    var basePresets = baseConfig.presets || [];
    var mergePresets = mergeConfig.presets || [];
    var basePlugins = baseConfig.plugins || [];
    var mergePlugins = mergeConfig.plugins || [];
    return __assign(__assign({}, baseConfig), { presets: __spreadArray(__spreadArray([], basePresets), mergePresets), plugins: __spreadArray(__spreadArray([], basePlugins), mergePlugins) });
}
exports.default = {
    chalk: chalk_1.default,
    loggerPrefix: loggerPrefix,
    logger: logger,
    success: success,
    warning: warning,
    error: error,
    noop: noop,
    getEnv: getEnv,
    isDev: isDev,
    isProduction: isProduction,
    isFunction: isFunction,
    isObject: isObject,
    isString: isString,
    requireModule: requireModule,
    getWebpackProxyPath: getWebpackProxyPath,
    mergeBabelConfig: mergeBabelConfig
};
