import MiniCssExtractPlugin from 'mini-css-extract-plugin';
import utils from '../utils';
import { RcbConfig } from '../getConfig';
const cssRegex = /\.css$/;

function getStyleLoader(rcb: RcbConfig, preLoader?: any) {
    const loader: any = [
        utils.isDev() ? require.resolve('style-loader') : MiniCssExtractPlugin.loader,
        { loader: require.resolve('css-loader'), options: { sourceMap: true } },
        {
            loader: require.resolve('postcss-loader'), options: {
                postcssOptions: {
                    plugins: [
                        require.resolve('postcss-flexbugs-fixes'),
                        [
                            require.resolve('postcss-preset-env'),
                            {
                                autoprefixer: {
                                    flexbox: 'no-2009',
                                },
                                stage: 3,
                            },
                        ],
                        require.resolve('postcss-normalize')
                    ]
                }
            }
        },
        { loader: require.resolve('resolve-url-loader'), options: { sourceMap: true, silent: true } }
    ];

    if (preLoader) {
        loader.push(preLoader);
    }

    return loader;
}

function getCssLoader(rcb: RcbConfig) {
    return ({
        test: cssRegex,
        use: getStyleLoader(rcb)
    });
}

getCssLoader.getStyleLoader = getStyleLoader;

export default getCssLoader;
