import path from 'path';
import utils from './utils';

function getPath(fileName: string) {
    const basePath = __dirname;

    return path.resolve(basePath, fileName);
}

function getLoader(filePath: string, ...args: any[]) {
    const getLoaderFn = utils.requireModule(filePath);

    if (utils.isFunction(getLoaderFn)) {
        return getLoaderFn(...args);
    }

    return {};
}

export default function getLoaders(...args: any[]) {
    const configPath = getPath('getLoaderConfig');
    return [
        getLoader(configPath + '/disabledMjsLoader', ...args),
        {
            oneOf: [
                'getCssLoader',
                'getLessLoader',
                'getTsLoader',
                'getBabelLoader',
                'getDevBabelLoader',
                'getUrlLoader',
                'getFileLoader',
            ].map(p => {
                return getLoader(configPath + '/' + p, ...args);
            })
        }
    ]
};
